SystemOrganization addCategory: #'XTream-Tests'!

TestCase subclass: #XtreamTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'XTream-Tests'!

!XtreamTests methodsFor: 'testing' stamp: 'nice 12/4/2009 04:24'!
testAppend
	| stream string |
	string := 'foo'.
	stream := string appendXtream.
	stream nextPutAll: 'bug'.
	self assert: stream contents = 'foobug'.
	self assert: string = 'foo' description: 'no side effect'! !

!XtreamTests methodsFor: 'testing' stamp: 'nice 12/4/2009 04:25'!
testAppendPointers
	| stream |
	stream := {0@0} appendXtream.
	stream nextPut: #cr; nextPut: #tab; nextPut: true.
	self assert: stream contents = {0@0. #cr. #tab. true}! !

!XtreamTests methodsFor: 'testing' stamp: 'nice 12/4/2009 04:26'!
testAsciiAPI
	| stream |
	stream := String new writeXtream.
	stream cr; space; tab; lf.
	stream := stream contents readXtream.
	#(cr space tab lf) do: [:e | self assert: (Character perform: e) = stream next].
	self assert: stream atEnd.
	
	stream := String new writeXtream.
	stream tab: 2; crlf; space: 3; crtab; crlf; crtab: 2.
	stream := stream contents readXtream.
	#(tab tab cr lf space space space cr tab cr lf cr tab tab) do: [:e | self assert: (Character perform: e) = stream next].
	self assert: stream atEnd.! !

!XtreamTests methodsFor: 'testing' stamp: 'nice 12/8/2009 17:47'!
testBlockEncodingDecoding
	| encoder decoder string1 string2 converter |
	converter := UTF8TextConverter new installLineEndConvention: nil.
	0
		to: 255
		do: [:i |
			encoder := String new writeXtream blockEncodeWith: converter.
			encoder nextPut: i asCharacter.
			self assert: encoder contents = (String with: i asCharacter) squeakToUtf8.
			
			decoder := (String with: i asCharacter) squeakToUtf8 readXtream blockDecodeWith: converter.
			self assert: decoder next asciiValue = i.
			self assert: decoder next = nil].
	
	string1 := ' ta sant mon brave'.
	string2 := (string1 squeakToUtf8 readXtream blockDecodeWith: converter) upToEnd.
	self assert: string1 = string2.
	string2 := (string1 squeakToUtf8 readXtream blockDecodeWith: converter) buffered upToEnd.
	self assert: string1 = string2.! !

!XtreamTests methodsFor: 'testing' stamp: 'nice 12/9/2009 00:09'!
testByteTextConverter
	| strings converterClasses |
	strings := {
		String newFrom: ((0 to: 255) collect: [:e | e asCharacter]).
	}.
	
	converterClasses := ByteTextConverter allSubclasses.
	converterClasses do: [:converterClass | 
		strings do: [:string | | converter stream encoded decoded encoded2 |
			converter := converterClass new.
			stream := string readStream.
			encoded := string select: [:e | (converter nextFromXtream: stream) notNil].
			stream := encoded readStream.
			decoded := encoded collect: [:e | converter nextFromXtream: stream].
			self assert: stream atEnd.
			stream := String new writeStream.
			converter next: decoded size putAll: decoded startingAt: 1 toXtream: stream.
			encoded2 := stream contents.
			self assert: (encoded2 collect: [:e | e charCode] as: Array) = (encoded collect: [:e | e charCode] as: Array).
			stream := String new writeStream.
			decoded do: [:e | converter nextPut: e toXtream: stream].
			encoded2 := stream contents.
			self assert: (encoded2 collect: [:e | e charCode] as: Array) = (encoded collect: [:e | e charCode] as: Array)]]! !

!XtreamTests methodsFor: 'testing' stamp: 'nice 12/8/2009 02:21'!
testComposite
	| string string1 string2 string3 string4 |
	string1 := 'this '.
	string2 := 'is'.
	string3 := ' a '.
	string4 := 'test'.
	string := (string1 , string2) , (string3 , string4).
	{
	(string1 readXtream , string2 readXtream) , (string3 readXtream , string4 readXtream).
	(string1 readXtream , (string2 readXtream , string3 readXtream)) , string4 readXtream.
	} do: [:stream |
		
		string do: [:e |
			self assert: e = stream next].
		self assert: stream atEnd.
	
		stream reset.
		self assert: stream position = 0.
		self assert: (stream upTo: Character space) = 'this'.
		self assert: (stream upToAnyOf: CharacterSet separators) = 'is'.
		self assert: (stream upToAll: 'est') = 'a t'.
		stream reset.
		self assert: (stream through: Character space) = 'this '.
		self assert: (stream throughAll: 'a t') = 'is a t'.
		stream reset.
		self assert: stream next = $t.
		self assert: stream peek = $h.
		stream skipTo: Character space.
		self assert: stream next =  Character space.
		stream skipThrough: Character space.
		self assert: stream upToEnd =  'a test'].! !

!XtreamTests methodsFor: 'testing' stamp: 'nice 12/8/2009 10:25'!
testEncodingDecoding
	| encoder decoder string1 string2 converter |
	converter := UTF8TextConverter new installLineEndConvention: nil.
	0
		to: 255
		do: [:i |
			encoder := String new writeXtream encodeWith: converter.
			encoder nextPut: i asCharacter.
			self assert: encoder contents = (String with: i asCharacter) squeakToUtf8.
			
			decoder := (String with: i asCharacter) squeakToUtf8 readXtream decodeWith: converter.
			self assert: decoder next asciiValue = i.
			self assert: decoder next = nil].
	
	string1 := ' ta sant mon brave'.
	string2 := (string1 squeakToUtf8 readXtream decodeWith: converter) upToEnd.
	self assert: string1 = string2.
	string2 := (string1 squeakToUtf8 readXtream decodeWith: converter) buffered upToEnd.
	self assert: string1 = string2.! !

!XtreamTests methodsFor: 'testing' stamp: 'nice 12/4/2009 02:25'!
testFileEncoding
	| foo longString contents |
	longString := String new: 4096 streamContents: [:strm | 0 to: 255 do: [:i | (i bitAnd: 16r7F) < 32 ifFalse: [strm print: i; space; nextPut: (Character value: i); cr]]].
	foo := (StandardFileStream newFileNamed: 'foo_utf8.cs') writeXtream ascii buffered encodeWith: UTF8TextConverter new.
	foo nextPutAll: longString.
	longString reverseDo: [:e | foo nextPut: e].
	foo close.
	
	foo := (StandardFileStream readOnlyFileNamed: 'foo_utf8.cs') readXtream ascii buffered.
	contents := foo upToEnd.
	foo close.
	self assert: contents = (longString squeakToUtf8 , longString reversed squeakToUtf8).

	foo := (StandardFileStream readOnlyFileNamed: 'foo_utf8.cs') readXtream ascii buffered decodeWith: UTF8TextConverter new..
	contents := foo upToEnd.
	foo close.
	self assert: contents = (longString , longString reversed).
	
	FileDirectory default deleteFileNamed: foo name! !

!XtreamTests methodsFor: 'testing' stamp: 'nice 12/8/2009 17:48'!
testFileRead
	| srcStream1 srcStream2 srcStream3 line1 line2 line3 char1 char2 char3 |
	srcStream1 := StandardFileStream readOnlyFileNamed: (SourceFiles at: 2) name.
	srcStream2 := (StandardFileStream readOnlyFileNamed: (SourceFiles at: 2) name) readXtream.
	srcStream3 := (StandardFileStream readOnlyFileNamed: (SourceFiles at: 2) name) readXtream buffered.
	srcStream1 ascii.
	srcStream2 ascii.
	srcStream3 ascii.
	
	[100 timesRepeat:
		[line1 := srcStream1 upTo: Character cr.
		line2 := srcStream2 upTo: Character cr.
		line3 := srcStream3 upTo: Character cr.
		self assert: line1 = line2.
		self assert: line1 = line3].
	100 timesRepeat:
		[line1 := srcStream1 nextLine.
		line2 := srcStream2 nextLine.
		line3 := srcStream3 nextLine.
		self assert: line1 = line2.
		self assert: line1 = line3].
	100 timesRepeat:
		[char1 := srcStream1 next.
		char2 := srcStream2 next.
		char3 := srcStream3 next.
		self assert: char1 = char2.
		self assert: char1 = char3].
	
	self assert: srcStream1 position = srcStream2 position.
	self assert: srcStream1 position = srcStream3 position.
	0 to: srcStream1 position by: srcStream1 position // 10 do: [:i |
		srcStream1 position: i.
		srcStream2 position: i.
		srcStream3 position: i.
		self assert: srcStream1 position = srcStream2 position.
		self assert: srcStream1 position = srcStream3 position.
		self assert: srcStream1 peek = srcStream2 peek.
		self assert: srcStream1 peek = srcStream3 peek.
		100 timesRepeat:
			[char1 := srcStream1 next.
			char2 := srcStream2 next.
			char3 := srcStream3 next.
			self assert: char1 = char2.
			self assert: char1 = char3]].
	srcStream1 position to: 0 by: (srcStream1 position // 10) negated do: [:i |
		srcStream1 position: i.
		srcStream2 position: i.
		srcStream3 position: i.
		self assert: srcStream1 position = srcStream2 position.
		self assert: srcStream1 position = srcStream3 position.
		self assert: srcStream1 peek = srcStream2 peek.
		self assert: srcStream1 peek = srcStream3 peek.
		100 timesRepeat:
			[char1 := srcStream1 next.
			char2 := srcStream2 next.
			char3 := srcStream3 next.
			self assert: char1 = char2.
			self assert: char1 = char3]].
	srcStream1 setToEnd.
	srcStream2 setToEnd.
	srcStream3 setToEnd.
	self assert: srcStream1 atEnd.
	self assert: srcStream2 atEnd.
	self assert: srcStream3 atEnd.
	self assert: srcStream1 peek = nil.
	self assert: srcStream2 peek = nil.
	self assert: srcStream3 peek = nil.
	srcStream1 skip: -744.
	srcStream2 skip: -744.
	srcStream3 skip: -744.
	self assert: srcStream1 position = srcStream2 position.
	self assert: srcStream1 position = srcStream3 position.
	self assert: srcStream1 peek = srcStream2 peek.
	self assert: srcStream1 peek = srcStream3 peek.
	line1 := srcStream1 next: 100.
	line2 := srcStream2 next: 100.
	line3 := srcStream3 next: 100.
	self assert: line1 = line2.
	self assert: line1 = line3.
	line1 := srcStream1 upToEnd.
	line2 := srcStream2 upToEnd.
	line3 := srcStream3 upToEnd.
	self assert: line1 = line2.
	self assert: line1 = line3.]

	ensure: [srcStream1 close. srcStream2 close. srcStream3 close].
	self assert: srcStream1 closed.
	self assert: srcStream2 closed.
	self assert: srcStream3 closed.
	! !

!XtreamTests methodsFor: 'testing' stamp: 'nice 12/3/2009 23:16'!
testFileWriteAndSkip
	| foo longString contents |
	longString := String new: 10000 streamContents: [:strm | 1 to: 10000 do: [:i | strm nextPut: 'abcdefghijklmnopqrstuvwxyz' atRandom]].
	foo := (StandardFileStream newFileNamed: 'foo_buffered.txt') writeXtream buffered.
	foo ascii.
	foo nextPut: $A.
	foo nextPutAll: longString.
	foo nextPut: $Z.
	foo skip: -1 - longString size.
	foo nextPutAll: longString reversed.
	foo skip: 1.
	longString do: [:e | foo nextPut: e].
	foo close.
	
	foo := (StandardFileStream readOnlyFileNamed: 'foo_buffered.txt') readXtream.
	foo ascii.
	contents := foo contents.
	foo close.
	self assert: contents = ('A' , longString reversed , 'Z' , longString).
	
	FileDirectory default deleteFileNamed: foo name! !

!XtreamTests methodsFor: 'testing' stamp: 'nice 12/9/2009 00:22'!
testMultiByteTextConverter
	| strings converterClasses |
	strings := {
		String newFrom: ((0 to: 255) collect: [:e | Unicode value: e]).
		String newFrom: ((0 to: 1023) collect: [:e | Unicode value: e]).
	}.
	
	converterClasses := {
		UTF8TextConverter . UTF16TextConverter .
		"CompoundTextConverter ."
		"EUCJPTextConverter . CNGBTextConverter . ShiftJISTextConverter . EUCKRTextConverter"}.
	converterClasses do: [:converterClass | 
		strings do: [:string |
			| converter stream string2 |
			converter := converterClass new.
			stream := String new writeXtream.
			converter next: string size putAll: string startingAt: 1 toXtream: stream.
			stream := stream contents readXtream.
			string do: [:e | | decoded |
				decoded := converter nextFromXtream: stream.
				self assert: e charCode = decoded charCode].
			self assert: stream atEnd.
	
			stream := String new writeXtream.
			string do: [:e | converter nextPut: e toXtream: stream].
			stream := stream contents readXtream.
			string2 := (String new: string size).
			converter readInto: string2 startingAt: 1 count: string2 size fromXtream: stream.
			self assert: stream atEnd.
			self assert: (string collect: [:e | e charCode] as: Array) = (string2 collect: [:e | e charCode] as: Array)]]! !

!XtreamTests methodsFor: 'testing' stamp: 'nice 12/4/2009 04:16'!
testPrintStore
	| stream |
	stream := String new writeXtream.
	stream print: true.
	self assert: stream contents = 'true'.
	
	stream := String new writeXtream.
	stream store: Float nan.
	self assert: stream contents = 'Float nan'.! !

!XtreamTests methodsFor: 'testing' stamp: 'nice 12/8/2009 10:15'!
testRead
	| string stream |
	string := 'this is a test'.
	stream := string readXtream.
	string do: [:e |
		self assert: e = stream next].
	self assert: stream atEnd.
	
	stream reset.
	self assert: stream position = 0.
	self assert: (stream upTo: Character space) = 'this'.
	self assert: (stream upToAnyOf: CharacterSet separators) = 'is'.
	self assert: (stream upToAll: 'est') = 'a t'.
	stream reset.
	self assert: (stream through: Character space) = 'this '.
	self assert: (stream throughAll: 'a t') = 'is a t'.
	stream reset.
	self assert: stream next = $t.
	self assert: stream peek = $h.
	stream skipTo: Character space.
	self assert: stream next =  Character space.
	stream skipThrough: Character space.
	self assert: stream upToEnd =  'a test'.! !

!XtreamTests methodsFor: 'testing' stamp: 'nice 12/2/2009 14:33'!
testReadCollect
	| string stream upper |
	string := 'this is a test'.
	stream := string readXtream.
	upper := stream collect: [:e | e asUppercase].
	
	self assert: upper contents = string asUppercase! !

!XtreamTests methodsFor: 'testing' stamp: 'nice 12/4/2009 12:25'!
testReadOverNil
	| collec stream eos |
	collec := #(#cr #lf true nil false).
	stream := collec readXtream.

	eos := stream goodEndOfStreamMark.
	self assert: eos notNil.
	stream endOfStreamAction: nil -> eos.

	self assert: stream isReadable.
	self assert: stream isPositionable.
	self deny: stream isWriteable.
	self assert: stream knowsItsSize.
	self assert: stream size = collec size.

	stream setToEnd.
	self assert: stream peek == eos.
	self assert: stream next == eos.
	stream reset.
	collec do: [:e | self assert: stream next = e].! !

!XtreamTests methodsFor: 'testing' stamp: 'nice 12/3/2009 14:48'!
testReadSelectReject
	| string stream vowels sep nonSep |
	string := 'this is a test'.
	stream := string readXtream.
	vowels := stream select: [:e | e isVowel].
	
	self assert: vowels contents = (string select: [:e | e isVowel]).
	
	sep := CharacterSet separators.
	stream := string readXtream.
	nonSep := stream reject: [:e | sep includes: e].
	self assert: nonSep contents = (string reject: [:e | sep includes: e]).! !

!XtreamTests methodsFor: 'testing' stamp: 'nice 12/8/2009 10:15'!
testSkip
	| string stream |
	string := 'this is a test'.
	stream := string readXtream.
	stream skip: 5.
	self assert: stream position = 5.
	self assert: stream upToEnd = 'is a test'.
	stream skip: -4.
	self assert: stream position = (string size - 4).
	self assert: stream upToEnd = 'test'.! !

!XtreamTests methodsFor: 'testing' stamp: 'nice 12/8/2009 10:16'!
testSkipThrough
	| string stream bytes |
	string := 'aababcabcd'.
	stream := string readXtream.
	
	stream skipThrough: $a.
	self assert: (stream upToEnd) = 'ababcabcd'..
	stream reset.
	stream skipThrough: $b.
	self assert: (stream upToEnd) = 'abcabcd'.
	stream reset.
	stream skipThrough: $c.
	self assert: (stream upToEnd) = 'abcd'.
	stream reset.
	stream skipThrough: $d.
	self assert: (stream upToEnd) = ''.
	stream reset.
	stream skipThrough: $e.
	self assert: (stream upToEnd) = ''.
	
	bytes := #[1 1 2 1 2 3 1 2 3 4].
	stream := CollectionReadXtream read: bytes.
	
	stream skipThrough: 1.
	self assert: (stream upToEnd) = #[1 2 1 2 3 1 2 3 4].
	stream reset.
	stream skipThrough: 2.
	self assert: (stream upToEnd) = #[1 2 3 1 2 3 4].
	stream reset.
	stream skipThrough: 3.
	self assert: (stream upToEnd) = #[1 2 3 4].
	stream reset.
	stream skipThrough: 4.
	self assert: (stream upToEnd) = #[].
	stream reset.
	stream skipThrough: 5.
	self assert: (stream upToEnd) = #[].! !

!XtreamTests methodsFor: 'testing' stamp: 'nice 12/8/2009 10:16'!
testSkipTo
	| string stream bytes |
	string := 'aababcabcd'.
	stream := string readXtream.
	
	stream skipTo: $a.
	self assert: (stream upToEnd) = string.
	stream reset.
	stream skipTo: $b.
	self assert: (stream upToEnd) = 'babcabcd'.
	stream reset.
	stream skipTo: $c.
	self assert: (stream upToEnd) = 'cabcd'.
	stream reset.
	stream skipTo: $d.
	self assert: (stream upToEnd) = 'd'.
	stream reset.
	stream skipTo: $e.
	self assert: (stream upToEnd) = ''.
	
	bytes := #[1 1 2 1 2 3 1 2 3 4].
	stream := CollectionReadXtream read: bytes.
	
	stream skipTo: 1.
	self assert: (stream upToEnd) = #[1 1 2 1 2 3 1 2 3 4].
	stream reset.
	stream skipTo: 2.
	self assert: (stream upToEnd) = #[2 1 2 3 1 2 3 4].
	stream reset.
	stream skipTo: 3.
	self assert: (stream upToEnd) = #[3 1 2 3 4].
	stream reset.
	stream skipTo: 4.
	self assert: (stream upToEnd) = #[4].
	stream reset.
	stream skipTo: 5.
	self assert: (stream upToEnd) = #[].! !

!XtreamTests methodsFor: 'testing' stamp: 'nice 12/8/2009 10:16'!
testThroughAll
	| string stream bytes |
	string := 'aababcabcd'.
	stream := string readXtream.
	
	self assert: (stream throughAll: 'a') = 'a'.
	self assert: (stream upToEnd) = 'ababcabcd'.
	stream reset.
	self assert: (stream throughAll: 'ab') = 'aab'.
	self assert: (stream upToEnd) = 'abcabcd'.
	stream reset.
	self assert: (stream throughAll: 'abc') = 'aababc'.
	self assert: (stream upToEnd) = 'abcd'.
	stream reset.
	self assert: (stream throughAll: 'abcd') = 'aababcabcd'.
	self assert: (stream upToEnd) = ''.
	stream reset.
	self assert: (stream throughAll: 'abe') = 'aababcabcd'.
	self assert: (stream upToEnd) = ''.
	
	bytes := #[1 1 2 1 2 3 1 2 3 4].
	stream := CollectionReadXtream read: bytes.
	
	self assert: (stream throughAll: #[1]) = #[1].
	self assert: (stream upToEnd) = #[1 2 1 2 3 1 2 3 4].
	stream reset.
	self assert: (stream throughAll: #[1 2]) = #[1 1 2].
	self assert: (stream upToEnd) = #[1 2 3 1 2 3 4].
	stream reset.
	self assert: (stream throughAll: #[1 2 3]) = #[1 1 2 1 2 3].
	self assert: (stream upToEnd) = #[1 2 3 4].
	stream reset.
	self assert: (stream throughAll: #[1 2 3 4]) = bytes.
	self assert: (stream upToEnd) = #[].
	stream reset.
	self assert: (stream throughAll: #[1 2 5]) = bytes.
	self assert: (stream upToEnd) = #[].! !

!XtreamTests methodsFor: 'testing' stamp: 'nice 12/8/2009 10:18'!
testUpToAll
	| string bytes |
	string := 'aababcabcd'.
	{string readXtream. 'zyx' , string , 'efg' readXtreamFrom: 4 to: 3 + string size} do: [:stream |
	
		self assert: (stream upToAll: 'a') = ''.
		self assert: (stream upToEnd) = 'ababcabcd'.
		stream reset.
		self assert: (stream upToAll: 'ab') = 'a'.
		self assert: (stream upToEnd) = 'abcabcd'.
		stream reset.
		self assert: (stream upToAll: 'abc') = 'aab'.
		self assert: (stream upToEnd) = 'abcd'.
		stream reset.
		self assert: (stream upToAll: 'abcd') = 'aababc'.
		self assert: (stream upToEnd) = ''.
		stream reset.
		self assert: (stream upToAll: 'abe') = 'aababcabcd'.
		self assert: (stream upToEnd) = ''].
	
	bytes := #[1 1 2 1 2 3 1 2 3 4].
	{bytes readXtream. #[0 0 0] , bytes , #[5 6 7] readXtreamFrom: 4 to: 3 + string size} do: [:stream |
	
		self assert: (stream upToAll: #[1]) = #[].
		self assert: (stream upToEnd) = #[1 2 1 2 3 1 2 3 4].
		stream reset.
		self assert: (stream upToAll: #[1 2]) = #[1].
		self assert: (stream upToEnd) = #[1 2 3 1 2 3 4].
		stream reset.
		self assert: (stream upToAll: #[1 2 3]) = #[1 1 2].
		self assert: (stream upToEnd) = #[1 2 3 4].
		stream reset.
		self assert: (stream upToAll: #[1 2 3 4]) = #[1 1 2 1 2 3].
		self assert: (stream upToEnd) = #[].
		stream reset.
		self assert: (stream upToAll: #[1 2 5]) = bytes.
		self assert: (stream upToEnd) = #[]].! !

!XtreamTests methodsFor: 'testing' stamp: 'nice 12/4/2009 12:28'!
testWrite
	| string stream |
	string := 'this is a test'.

	stream := String new writeXtream.
	self deny: stream isReadable.
	self assert: stream isPositionable.
	self assert: stream isWriteable.
	
	string do: [:e | stream nextPut: e].
	self assert: stream contents = string.
	
	stream := String new writeXtream.
	stream nextPutAll: string.
	self assert: stream contents = string.
	
	stream := String new writeXtream.
	stream next: 5 putAll: string.
	self assert: stream contents = (string copyFrom: 1 to: 5).
	
	stream := String new writeXtream.
	stream next: 5 putAll: string startingAt: 2.
	self assert: stream contents = (string copyFrom: 2 to: 6).! !

!XtreamTests methodsFor: 'testing' stamp: 'nice 12/2/2009 14:34'!
testWriteCollect
	| string stream upper |
	string := 'this is a test'.
	stream := String new writeXtream.
	upper := stream collect: [:e | e asUppercase].
	upper nextPutAll: string.
	self assert: upper contents = string asUppercase! !

!XtreamTests methodsFor: 'testing' stamp: 'nice 12/4/2009 04:25'!
testWritePointers
	| stream |
	stream := Array new writeXtream.
	stream nextPut: #cr; nextPut: #tab; nextPut: true.
	self assert: stream contents = #(cr tab true)! !

!XtreamTests methodsFor: 'testing' stamp: 'nice 12/3/2009 14:55'!
testWriteSelectReject
	| string stream vowels sep nonSep |
	string := 'this is a test'.
	stream := String new writeXtream.
	
	vowels := stream select: [:e | e isVowel].
	vowels nextPutAll: string.
	self assert: vowels contents = (string select: [:e | e isVowel]).
	
	sep := CharacterSet separators.
	stream := String new writeXtream.
	nonSep := stream reject: [:e | sep includes: e].
	nonSep nextPutAll: string.
	self assert: nonSep contents = (string reject: [:e | sep includes: e]).! !

!XtreamTests methodsFor: 'testing' stamp: 'nice 12/4/2009 15:49'!
testWriteWide
	| string stream |
	string := 'this is a test' copyWith: 1000 asCharacter.

	stream := String new writeXtream.
	string do: [:e | stream nextPut: e].
	self assert: stream contents = string.
	
	stream := String new writeXtream.
	stream nextPutAll: string.
	self assert: stream contents = string.! !
